@@ -1,8 +1,10 @@
 from prophets import Isaiah, TwitterParser, Elijiah
-import sys
+import sys, logging
 from pprint import pprint
 from datetime import datetime, timedelta
 
+logger = logging.getLogger(__name__)
+logger.setLevel(logging.ERROR)
 if __name__ == "__main__":
     print(f"Abraham Version: {open('version').read().strip()}")
 
@@ -15,16 +17,6 @@ if __name__ == "__main__":
         bearer_token=open("keys/twitter-bearer-token").read().strip(),
     )  # splitting means that it recursively splits a large text into sentences and analyzes each individually
 
-    newest = datetime.now()
-    oldest = newest - timedelta(days=1)  # datetime one week ago = the finish line
-
-    scores = darthvader.news_summary(
-        *args, oldest, newest
-    )  # latest date to get news from
-    print("Total\n--")
-    pprint(scores)
-
-    """
     scores = darthvader.news_summary(*args)  # latest date to get news from
     print("News\n--")
     pprint(scores)
@@ -32,4 +24,3 @@ if __name__ == "__main__":
     scores = darthvader.twitter_summary(*args, size=100)  # latest date to get news from
     print("\nTwitter\n--")
     pprint(scores)
-    """
\ No newline at end of file
